@@ -26,6 +26,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
+#include <GL/gl.h>
 #include <GL/glx.h>
 
 #include <gdk/gdkgldefs.h>
@@ -85,8 +86,15 @@ typedef XID GLXPbufferSGIX;
 #define GLX_EXT_import_context 1
 #endif
 
-#include <gdk/GL/glxext.h>
-#include <gdk/GL/glxext-extra.h>
+/* Avoid old glxext.h bug. */
+#if !defined(GLX_SGIX_video_source) && !defined(GDKGLEXT_NEED_GLXVIDEOSOURCESGIX_TYPEDEF)
+#define GLX_SGIX_video_source 1
+#endif
+
+#undef __glxext_h_
+#undef GLX_GLXEXT_VERSION
+#include <gdk/glext/glxext.h>
+#include <gdk/glext/glxext-extra.h>
 
 /*
  * GLX_VERSION_1_3
@@ -831,6 +839,27 @@ struct _GdkGL_GLX_OML_sync_control
 
 GdkGL_GLX_OML_sync_control *gdk_gl_get_GLX_OML_sync_control (GdkGLConfig *glconfig);
 
+/*
+ * GLX_MESA_agp_offset
+ */
+
+/* glXGetAGPOffsetMESA */
+typedef GLuint ( * GdkGLProc_glXGetAGPOffsetMESA) (const GLvoid *pointer);
+GdkGLProc    gdk_gl_get_glXGetAGPOffsetMESA (void);
+#define      gdk_gl_glXGetAGPOffsetMESA(proc, pointer) \
+  ( ((GdkGLProc_glXGetAGPOffsetMESA) (proc)) (pointer) )
+
+/* proc struct */
+
+typedef struct _GdkGL_GLX_MESA_agp_offset GdkGL_GLX_MESA_agp_offset;
+
+struct _GdkGL_GLX_MESA_agp_offset
+{
+  GdkGLProc_glXGetAGPOffsetMESA glXGetAGPOffsetMESA;
+};
+
+GdkGL_GLX_MESA_agp_offset *gdk_gl_get_GLX_MESA_agp_offset (GdkGLConfig *glconfig);
+
 /*
  * GLX_NV_vertex_array_range
  */
